@@ -1,21 +1,21 @@
 /*
 	Audio File Library
-	Copyright (C) 1998-2000, 2011, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, 2011-2013, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
-	modify it under the terms of the GNU Library General Public
+	modify it under the terms of the GNU Lesser General Public
 	License as published by the Free Software Foundation; either
-	version 2 of the License, or (at your option) any later version.
+	version 2.1 of the License, or (at your option) any later version.
 
 	This library is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	Library General Public License for more details.
+	Lesser General Public License for more details.
 
-	You should have received a copy of the GNU Library General Public
+	You should have received a copy of the GNU Lesser General Public
 	License along with this library; if not, write to the
-	Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-	Boston, MA  02111-1307  USA.
+	Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+	Boston, MA  02110-1301  USA
 */
 
 /*
@@ -30,7 +30,6 @@
 
 #include <assert.h>
 #include <stdint.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -48,7 +47,7 @@ const int _af_next_compression_types[_AF_NEXT_NUM_COMPTYPES] =
 	AF_COMPRESSION_G711_ALAW
 };
 
-static _AFfilesetup next_default_filesetup =
+static const _AFfilesetup nextDefaultFileSetup =
 {
 	_AF_VALID_FILESETUP,	/* valid */
 	AF_FILE_NEXTSND,	/* fileFormat */
@@ -107,18 +106,9 @@ status NeXTFile::readInit(AFfilesetup setup)
 {
 	uint32_t id, offset, length, encoding, sampleRate, channelCount;
 
-	instruments = NULL;
-	instrumentCount = 0;
+	m_fh->seek(0, File::SeekFromBeginning);
 
-	miscellaneous = NULL;
-	miscellaneousCount = 0;
-
-	tracks = NULL;	/* Allocate this later. */
-	trackCount = 1;
-
-	fh->seek(0, File::SeekFromBeginning);
-
-	fh->read(&id, 4);
+	m_fh->read(&id, 4);
 	assert(!memcmp(&id, ".snd", 4));
 
 	readU32(&offset);
@@ -127,26 +117,27 @@ status NeXTFile::readInit(AFfilesetup setup)
 	readU32(&sampleRate);
 	readU32(&channelCount);
 
-#ifdef DEBUG
-	printf("id, offset, length, encoding, sampleRate, channelCount:\n"
-		" %d %d %d %d %d %d\n",
-		id, offset, length, encoding, sampleRate, channelCount);
-#endif
+	if (!channelCount)
+	{
+		_af_error(AF_BAD_CHANNELS, "invalid file with 0 channels");
+		return AF_FAIL;
+	}
 
-	Track *track = _af_track_new();
+	Track *track = allocateTrack();
 	if (!track)
 		return AF_FAIL;
 
-	tracks = track;
-
 	track->f.byteOrder = AF_BYTEORDER_BIGENDIAN;
+	track->f.sampleRate = sampleRate;
+	track->f.channelCount = channelCount;
+	track->f.framesPerPacket = 1;
 
 	/* Override the compression type later if necessary. */
 	track->f.compressionType = AF_COMPRESSION_NONE;
 
 	track->fpos_first_frame = offset;
 
-	off_t lengthAvailable = fh->length() - offset;
+	off_t lengthAvailable = m_fh->length() - offset;
 	if (length == _AU_LENGTH_UNSPECIFIED || static_cast<off_t>(length) > lengthAvailable)
 		length = lengthAvailable;
 
@@ -158,11 +149,15 @@ status NeXTFile::readInit(AFfilesetup setup)
 			track->f.sampleWidth = 16;
 			track->f.sampleFormat = AF_SAMPFMT_TWOSCOMP;
 			track->f.compressionType = AF_COMPRESSION_G711_ULAW;
+			track->f.byteOrder = _AF_BYTEORDER_NATIVE;
+			track->f.bytesPerPacket = track->f.channelCount;
 			break;
 		case _AU_FORMAT_ALAW_8:
 			track->f.sampleWidth = 16;
 			track->f.sampleFormat = AF_SAMPFMT_TWOSCOMP;
 			track->f.compressionType = AF_COMPRESSION_G711_ALAW;
+			track->f.byteOrder = _AF_BYTEORDER_NATIVE;
+			track->f.bytesPerPacket = track->f.channelCount;
 			break;
 		case _AU_FORMAT_LINEAR_8:
 			track->f.sampleWidth = 8;
@@ -197,19 +192,13 @@ status NeXTFile::readInit(AFfilesetup setup)
 			return AF_FAIL;
 	}
 
+	if (track->f.isUncompressed())
+		track->f.computeBytesPerPacketPCM();
+
 	_af_set_sample_format(&track->f, track->f.sampleFormat, track->f.sampleWidth);
 
-	track->f.sampleRate = sampleRate;
-	track->f.channelCount = channelCount;
-	int frameSize = _af_format_frame_size(&track->f, false);
-	track->totalfframes = length / frameSize;
+	track->computeTotalFileFrames();
 
-#ifdef DEBUG
-	printf("_af_next_read_init\n");
-	_af_print_filehandle(file);
-#endif
-
-	/* The file has been parsed successfully. */
 	return AF_SUCCEED;
 }
 
@@ -250,7 +239,7 @@ AFfilesetup NeXTFile::completeSetup(AFfilesetup setup)
 			track->f.sampleWidth != 24 &&
 			track->f.sampleWidth != 32)
 		{
-			_af_error(AF_BAD_WIDTH, "invalid sample width %d for NeXT file (only 8-, 16-, 24-, and 32-bit data are allowed)");
+			_af_error(AF_BAD_WIDTH, "invalid sample width %d for NeXT file (only 8-, 16-, 24-, and 32-bit data are allowed)", track->f.sampleWidth);
 			return AF_NULL_FILESETUP;
 		}
 	}
@@ -263,12 +252,18 @@ AFfilesetup NeXTFile::completeSetup(AFfilesetup setup)
 		return AF_NULL_FILESETUP;
 	}
 
-	if (track->f.byteOrder != AF_BYTEORDER_BIGENDIAN && track->byteOrderSet)
+	if (track->f.isUncompressed() &&
+		track->byteOrderSet &&
+		track->f.byteOrder != AF_BYTEORDER_BIGENDIAN &&
+		track->f.isByteOrderSignificant())
 	{
 		_af_error(AF_BAD_BYTEORDER, "NeXT format supports only big-endian data");
-		track->f.byteOrder = AF_BYTEORDER_BIGENDIAN;
+		return AF_NULL_FILESETUP;
 	}
 
+	if (track->f.isUncompressed())
+		track->f.byteOrder = AF_BYTEORDER_BIGENDIAN;
+
 	if (track->aesDataSet)
 	{
 		_af_error(AF_BAD_FILESETUP, "NeXT files cannot have AES data");
@@ -293,7 +288,7 @@ AFfilesetup NeXTFile::completeSetup(AFfilesetup setup)
 		return AF_NULL_FILESETUP;
 	}
 
-	return _af_filesetup_copy(setup, &next_default_filesetup, false);
+	return _af_filesetup_copy(setup, &nextDefaultFileSetup, false);
 }
 
 static uint32_t nextencodingtype (AudioFormat *format);
@@ -308,7 +303,7 @@ status NeXTFile::writeHeader()
 {
 	Track *track = getTrack();
 
-	if (fh->seek(0, File::SeekFromBeginning) != 0)
+	if (m_fh->seek(0, File::SeekFromBeginning) != 0)
 		_af_error(AF_BAD_LSEEK, "bad seek");
 
 	uint32_t offset = track->fpos_first_frame;
@@ -317,7 +312,7 @@ status NeXTFile::writeHeader()
 	uint32_t sampleRate = track->f.sampleRate;
 	uint32_t channelCount = track->f.channelCount;
 
-	fh->write(".snd", 4);
+	m_fh->write(".snd", 4);
 	writeU32(&offset);
 	writeU32(&length);
 	writeU32(&encoding);
@@ -359,21 +354,13 @@ static uint32_t nextencodingtype (AudioFormat *format)
 
 status NeXTFile::writeInit(AFfilesetup setup)
 {
-	if (_af_filesetup_make_handle(setup, this) == AF_FAIL)
+	if (initFromSetup(setup) == AF_FAIL)
 		return AF_FAIL;
 
-	if (miscellaneousCount > 0)
-	{
-		_af_error(AF_BAD_NUMMISC, "NeXT format supports no miscellaneous chunks");
-		return AF_FAIL;
-	}
-
 	writeHeader();
 
 	Track *track = getTrack();
 	track->fpos_first_frame = 28;
 
-	track->f.byteOrder = AF_BYTEORDER_BIGENDIAN;
-
 	return AF_SUCCEED;
 }
