@@ -4,19 +4,19 @@
 	Copyright (C) 2010-2013, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
-	modify it under the terms of the GNU Library General Public
+	modify it under the terms of the GNU Lesser General Public
 	License as published by the Free Software Foundation; either
-	version 2 of the License, or (at your option) any later version.
+	version 2.1 of the License, or (at your option) any later version.
 
 	This library is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-	Library General Public License for more details.
+	Lesser General Public License for more details.
 
-	You should have received a copy of the GNU Library General Public
+	You should have received a copy of the GNU Lesser General Public
 	License along with this library; if not, write to the
-	Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-	Boston, MA  02111-1307  USA.
+	Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+	Boston, MA  02110-1301  USA
 */
 
 #include "config.h"
@@ -82,9 +82,9 @@ bool _af_g711_format_ok (AudioFormat *f)
 class G711 : public FileModule
 {
 public:
-	static Module *createCompress(Track *trk, File *fh, bool canSeek,
+	static G711 *createCompress(Track *trk, File *fh, bool canSeek,
 		bool headerless, AFframecount *chunkframes);
-	static Module *createDecompress(Track *trk, File *fh, bool canSeek,
+	static G711 *createDecompress(Track *trk, File *fh, bool canSeek,
 		bool headerless, AFframecount *chunkframes);
 
 	virtual const char *name() const OVERRIDE
@@ -114,7 +114,7 @@ G711::G711(Mode mode, Track *track, File *fh, bool canSeek) :
 		track->f.compressionParams = AU_NULL_PVLIST;
 }
 
-Module *G711::createCompress(Track *track, File *fh,
+G711 *G711::createCompress(Track *track, File *fh,
 	bool canSeek, bool headerless, AFframecount *chunkframes)
 {
 	return new G711(Compress, track, fh, canSeek);
@@ -183,7 +183,7 @@ void G711::describe()
 	}
 }
 
-Module *G711::createDecompress(Track *track, File *fh,
+G711 *G711::createDecompress(Track *track, File *fh,
 	bool canSeek, bool headerless, AFframecount *chunkframes)
 {
 	return new G711(Decompress, track, fh, canSeek);
@@ -234,13 +234,13 @@ void G711::reset2()
 	m_track->frames2ignore = 0;
 }
 
-Module *_AFg711initcompress(Track *track, File *fh, bool canSeek,
+FileModule *_AFg711initcompress(Track *track, File *fh, bool canSeek,
 	bool headerless, AFframecount *chunkFrames)
 {
 	return G711::createCompress(track, fh, canSeek, headerless, chunkFrames);
 }
 
-Module *_AFg711initdecompress(Track *track, File *fh, bool canSeek,
+FileModule *_AFg711initdecompress(Track *track, File *fh, bool canSeek,
 	bool headerless, AFframecount *chunkFrames)
 {
 	return G711::createDecompress(track, fh, canSeek, headerless, chunkFrames);
